# openrelik-worker-common
Common utilities for OpenRelik workers

# Run Tests
```
poetry install --with test --no-root
poetry run pytest --cov=.
```

##### Obligatory Fine Print
This is not an official Google product (experimental or otherwise), it is just code that happens to be owned by Google.
